@@ -100,6 +100,16 @@ def export(obj: Object, target_path: Path) -> None:
                 write_bytes(audio_data, target_path.joinpath(audio_name).with_suffix(".wav"))
         case MonoBehaviour():
             tree = obj.read_typetree()
+            # Some MonoBehaviours have the same file path. When this happens,
+            # unique file names are generated to prevent overwriting data.
+            if target_path.with_suffix(".json").is_file():
+                target_path = target_path.with_stem(target_path.stem + "_1")
+                index = 1
+                while target_path.with_suffix(".json").is_file():
+                    index += 1
+                    new_name = f"_{index}".join(target_path.stem.rsplit(f"_{index-1}", 1))
+                    target_path = target_path.with_stem(new_name)
+
             write_object(tree, target_path)
 
 
